sphinx_basic_ng: A modern skeleton for Sphinx themes.
=====================================================

Description
-----------

A modern skeleton for Sphinx themes.

License
-------

Upstream Contact
----------------

https://pypi.org/project/sphinx-basic-ng/

